#include "license.h" 
int auth_result;
static gboolean
on_tensec_timeout (gpointer user_data)
{
  GMainLoop *loop = user_data;
  g_main_loop_quit (loop);
  return FALSE;
}
static void
check_authorization_cb (PolkitAuthority *authority,
                        GAsyncResult    *res,
                        gpointer         user_data)
{
  GMainLoop *loop = user_data;
  PolkitAuthorizationResult *result;
  GError *error;

  error = NULL;
  result = polkit_authority_check_authorization_finish (authority, res, &error);
  if (error != NULL)
    {
      g_print ("Error checking authorization: %s\n", error->message);
      g_error_free (error);
    }
  else
    {
      const gchar *result_str;
      if (polkit_authorization_result_get_is_authorized (result))
        {
          result_str = "authorized";
          auth_result = 1;
        }
      else if (polkit_authorization_result_get_is_challenge (result))
        {
          result_str = "challenge";
          auth_result = 0;
        }
      else
        {
          result_str = "not authorized";
          auth_result = 0;
        }

    //  g_print ("Authorization result: %s\n", result_str);
    }

  on_tensec_timeout(loop);
}

static gboolean
do_cancel (GCancellable *cancellable)
{
//  g_print ("Timer has expired; cancelling authorization check\n");
  g_cancellable_cancel (cancellable);
  return FALSE;
}

int verify()
{
  pid_t parent_pid;
  const gchar *action_id;
  GMainLoop *loop;
  PolkitSubject *subject;
  PolkitAuthority *authority;
  GCancellable *cancellable;

  g_type_init ();

//  action_id = "org.freedesktop.policykit.exec";
  action_id = "org.freedesktop.licmanager.exec"; 
  //action_id = argv[1]; 


  loop = g_main_loop_new (NULL, FALSE);

  authority = polkit_authority_get();

  /* Typically mechanisms will use a PolkitSystemBusName since most
 *    * clients communicate with the mechanism via D-Bus. However for
 *       * this simple example we use the process id of the calling process.
 *          *
 *             * Note that if the parent was reaped we have to be careful not to
 *                * check if init(1) is authorized (it always is).
 *                   */
  parent_pid = getppid ();
  //printf("pid = %d\n",parent_pid);
  if (parent_pid == 1)
    {
      g_printerr ("Parent process was reaped by init(1)\n");
      return 1;
    }
  subject = polkit_unix_process_new (parent_pid);

  cancellable = g_cancellable_new ();

 // g_print ("Will cancel authorization check in 10 seconds\n");

  /* Set up a 10 second timer to cancel the check */
/*  g_timeout_add (10 * 1000,
                 (GSourceFunc) do_cancel,
                 cancellable);
*/
  polkit_authority_check_authorization (authority,
                                        subject,
                                        action_id,
                                        NULL, /* PolkitDetails */
                                        POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION,
                                        cancellable,
                                        (GAsyncReadyCallback) check_authorization_cb,
                                        loop);

  g_main_loop_run (loop);

  g_object_unref (authority);
  g_object_unref (subject);
  g_object_unref (cancellable);
  g_main_loop_unref (loop);

  return 0;
}
